/*
 * Copyright 2012-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.spring.initializr.generator.language;

import java.util.List;

/**
 * A representation of something that can be annotated.
 *
 * @author Andy Wilkinson
 * @author Stephane Nicoll
 */
public interface Annotatable {

	/**
	 * Return the {@link AnnotationContainer} to use to configure the annotations of this
	 * element.
	 * @return the annotation container
	 */
	AnnotationContainer annotations();

	@Deprecated(since = "0.20.0", forRemoval = true)
	default void annotate(Annotation annotation) {
		annotations().add(annotation.getClassName(), (builder) -> builder.from(annotation));
	}

	@Deprecated(since = "0.20.0", forRemoval = true)
	default List<Annotation> getAnnotations() {
		return annotations().values().toList();
	}

}
